"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OperationExecutionRequestBuilder = void 0;
class OperationExecutionRequestBuilder {
    constructor() {
        this.request = {};
    }
    get(path) {
        this.request = Object.assign(Object.assign({}, this.request), { method: 'get', path });
        return this;
    }
    put(path) {
        this.request = Object.assign(Object.assign({}, this.request), { method: 'put', path });
        return this;
    }
    post(path) {
        this.request = Object.assign(Object.assign({}, this.request), { method: 'post', path });
        return this;
    }
    delete(path) {
        this.request = Object.assign(Object.assign({}, this.request), { method: 'delete', path });
        return this;
    }
    options(path) {
        this.request = Object.assign(Object.assign({}, this.request), { method: 'options', path });
        return this;
    }
    head(path) {
        this.request = Object.assign(Object.assign({}, this.request), { method: 'head', path });
        return this;
    }
    patch(path) {
        this.request = Object.assign(Object.assign({}, this.request), { method: 'patch', path });
        return this;
    }
    trace(path) {
        this.request = Object.assign(Object.assign({}, this.request), { method: 'trace', path });
        return this;
    }
    query(query) {
        this.request = Object.assign(Object.assign({}, this.request), { query });
        return this;
    }
    send(mediaType, content) {
        if (typeof mediaType === 'object') {
            this.request.body = {
                mediaType: 'application/json',
                content: mediaType
            };
            return this;
        }
        if (typeof mediaType !== 'string') {
            throw new TypeError('Expected a string as media type');
        }
        if (content === undefined) {
            throw new TypeError('Expected something as content');
        }
        this.request.body = {
            mediaType,
            content
        };
        return this;
    }
    header() {
        throw new Error('Not implemented');
    }
    cookie() {
        throw new Error('Not implemented');
    }
    auth(securitiesOrSchemeName, scopes) {
        if (typeof securitiesOrSchemeName === 'string') {
            this.request.securities = Object.assign(Object.assign({}, this.request.securities), { [securitiesOrSchemeName]: scopes === undefined ? true : scopes });
        }
        else {
            this.request.securities = securitiesOrSchemeName;
        }
        return this;
    }
    build() {
        if (this.request.method === undefined || this.request.path === undefined) {
            throw new Error('Empty request: forgot to call `get`, `post`..?');
        }
        return this.request;
    }
}
exports.OperationExecutionRequestBuilder = OperationExecutionRequestBuilder;
//# sourceMappingURL=request.js.map